@@ -5,8 +5,8 @@
 ;; Author: Thanos Apollo <public@thanosapollo.org>
 ;; Keywords: extensions youtube videos
 ;; URL: https://thanosapollo.org/projects/yeetube/
-;; Package-Version: 2.1.11
-;; Package-Revision: 2eddda6d9305
+;; Package-Version: 2.1.12
+;; Package-Revision: 77e816972a70
 
 ;; Package-Requires: ((emacs "27.2") (compat "29.1.4.2"))
 
@@ -141,7 +141,7 @@ Valid options include:
   :prefix 'yeetube-face)
 
 (defcustom yeetube-thumbnail-size '(120 . 90)
-  "Thumbnail size (height width)."
+  "Thumbnail size (width . height)."
   :type '(cons integer integer)
   :group 'yeetube)
 
@@ -322,12 +322,10 @@ This is a variable watcher function that writes NEW-VALUE to the saved
 videos file whenever `yeetube-saved-videos' changes.  _SYMBOL is the
 variable being watched, _WHERE indicates the type of change, and
 _ENVIRONMENT is the lexical environment."
-  (with-temp-buffer (find-file (concat user-emacs-directory "yeetube"))
-		    (erase-buffer)
-		    (setf yeetube-saved-videos new-value)
-		    (insert (pp-to-string yeetube-saved-videos))
-		    (save-buffer)
-		    (kill-buffer)))
+  (let ((file-path (concat user-emacs-directory "yeetube")))
+    (with-temp-buffer
+      (insert (pp-to-string new-value))
+      (write-region (point-min) (point-max) file-path))))
 
 (defvar yeetube-filter-code-alist
   '(("Relevance" . "EgIQAQ%253D%253D")
@@ -360,7 +358,7 @@ _ENVIRONMENT is the lexical environment."
 				#'pop-to-buffer-same-window
 			      #'pop-to-buffer)))
     (unwind-protect
-        (if-let* ((err (plist-get :error status)))
+        (if-let* ((err (plist-get status :error)))
             (message "Error %s in retrieving yeetube results: %S" (car err) (cdr err))
           (with-temp-buffer
             (set-buffer-multibyte t)
@@ -380,28 +378,33 @@ _ENVIRONMENT is the lexical environment."
            (url-retrieve url #'yeetube--callback nil 'silent 'inhibit-cookies))
 	(url-retrieve url #'yeetube--callback nil 'silent 'inhibit-cookies)))))
 
+(defun yeetube--extract-image (status)
+  "Extract thumbnail image from the current URL callback buffer.
+Return the image sized per `yeetube-thumbnail-size', or nil on error."
+  (unless (plist-get status :error)
+    (when-let* ((handle (mm-dissect-buffer t))
+                (image (mm-get-image handle)))
+      (setf (image-property image :max-width) (car yeetube-thumbnail-size)
+            (image-property image :max-height) (cdr yeetube-thumbnail-size))
+      image)))
+
 (defun yeetube--image-callback (status entry buffer)
   "Yeetube callback for thumbnail images handling STATUS.
 Image is inserted in BUFFER for ENTRY."
-  (let ((url-buffer (current-buffer)))
-    (unwind-protect
-        (if-let* ((err (plist-get status :error)))
-            (message "Error %s in retrieving a thumbnail: %S" (car err) (cdr err))
-          (if-let* ((handle (mm-dissect-buffer t))
-                    (image (mm-get-image handle)))
-              (progn
-                (setf (image-property image :max-width) (car yeetube-thumbnail-size)
-                      (image-property image :max-height) (cdr yeetube-thumbnail-size))
-                ;; Debugging Statement
-                ;; (message "Retrieved and processing image for %s" (plist-get entry :title))
-                (with-current-buffer buffer
-                  (with-silent-modifications
-                    (save-excursion
-                      (goto-char (point-min))
-                      (search-forward (format "[[%s.jpg]]" (car entry)))
-                      (add-text-properties (match-beginning 0) (match-end 0)
-                                           `(display ,image)))))))
-	  (kill-buffer url-buffer)))))
+  (let* ((url-buffer (current-buffer))
+         (image (yeetube--extract-image status)))
+    (kill-buffer url-buffer)
+    (when image
+      (when-let* ((vec (cadr (assoc (car entry) yeetube-content))))
+        (aset vec 0 (propertize (aref vec 0) 'display image)))
+      (when (get-buffer buffer)
+        (with-current-buffer buffer
+          (with-silent-modifications
+            (save-excursion
+              (goto-char (point-min))
+              (when (search-forward (format "[[%s.jpg]]" (car entry)) nil t)
+                (add-text-properties (match-beginning 0) (match-end 0)
+                                     `(display ,image))))))))))
 
 (defun yeetube--retrieve-thumbnail (url str buffer)
   "Retrieve thumbnail from URL and show it in place of STR in BUFFER."
@@ -679,7 +682,7 @@ FIELDS-FACE-PAIRS is a list of fields and faces."
   "v" #'yeetube-mpv-toggle-video
   "V" #'yeetube-mpv-toggle-no-video-flag
   "s" #'yeetube-save-video
-  "S" #'yeetube-channel-streams
+  "L" #'yeetube-channel-streams
   "P" #'yeetube-play-saved-video
   "r" #'yeetube-replay
   "T" #'yeetube-mpv-toggle-torsocks
@@ -688,8 +691,9 @@ FIELDS-FACE-PAIRS is a list of fields and faces."
 
 (defun yeetube--sort-views (a b)
   "Sort entries A and B by view count."
-  (let ((views-a (string-to-number (replace-regexp-in-string "," "" (aref (cadr a) 2))))
-        (views-b (string-to-number (replace-regexp-in-string "," "" (aref (cadr b) 2)))))
+  (let* ((idx (if yeetube-display-thumbnails-p 2 1))
+         (views-a (string-to-number (replace-regexp-in-string "," "" (aref (cadr a) idx))))
+         (views-b (string-to-number (replace-regexp-in-string "," "" (aref (cadr b) idx)))))
     (< views-a views-b)))
 
 (defun yeetube--duration-to-seconds (duration)
@@ -704,8 +708,9 @@ FIELDS-FACE-PAIRS is a list of fields and faces."
 
 (defun yeetube--sort-duration (a b)
   "Sort entries A and B by duration."
-  (let ((duration-a (yeetube--duration-to-seconds (aref (cadr a) 3)))
-        (duration-b (yeetube--duration-to-seconds (aref (cadr b) 3))))
+  (let* ((idx (if yeetube-display-thumbnails-p 3 2))
+         (duration-a (yeetube--duration-to-seconds (aref (cadr a) idx)))
+         (duration-b (yeetube--duration-to-seconds (aref (cadr b) idx))))
     (< duration-a duration-b)))
 
 (defun yeetube--parse-relative-date (date)
@@ -727,8 +732,9 @@ FIELDS-FACE-PAIRS is a list of fields and faces."
 
 (defun yeetube--sort-date (a b)
   "Sort entries A and B by relative date."
-  (let ((date-a (yeetube--parse-relative-date (aref (cadr a) 4)))
-        (date-b (yeetube--parse-relative-date (aref (cadr b) 4))))
+  (let* ((idx (if yeetube-display-thumbnails-p 4 3))
+         (date-a (yeetube--parse-relative-date (aref (cadr a) idx)))
+         (date-b (yeetube--parse-relative-date (aref (cadr b) idx))))
     (< date-a date-b)))
 
 (defun yeetube--tabulated-list-format (thumbnail-p)
@@ -757,6 +763,7 @@ If THUMBNAIL-P is non-nil, display thumbnails."
 (define-derived-mode yeetube-mode tabulated-list-mode "Yeetube"
   "Yeetube mode."
   :keymap yeetube-mode-map
+  (setq-local truncate-string-ellipsis " ")
   (yeetube-tabulated-list)
   (setq-local yeetube-mpv-show-status t)
   (display-line-numbers-mode 0)
